# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEntityAliasResult',
]

@pulumi.output_type
class GetEntityAliasResult(dict):
    def __init__(__self__, *,
                 canonical_id: _builtins.str,
                 creation_time: _builtins.str,
                 id: _builtins.str,
                 last_update_time: _builtins.str,
                 merged_from_canonical_ids: Sequence[_builtins.str],
                 metadata: Mapping[str, _builtins.str],
                 mount_accessor: _builtins.str,
                 mount_path: _builtins.str,
                 mount_type: _builtins.str,
                 name: _builtins.str):
        """
        :param _builtins.str canonical_id: Canonical ID of the Alias
        :param _builtins.str creation_time: Creation time of the Alias
        :param _builtins.str id: ID of the alias
        :param _builtins.str last_update_time: Last update time of the alias
        :param Sequence[_builtins.str] merged_from_canonical_ids: List of canonical IDs merged with this alias
        :param Mapping[str, _builtins.str] metadata: Arbitrary metadata
        :param _builtins.str mount_accessor: Authentication mount acccessor which this alias belongs to
        :param _builtins.str mount_path: Authentication mount path which this alias belongs to
        :param _builtins.str mount_type: Authentication mount type which this alias belongs to
        :param _builtins.str name: Name of the alias
        """
        pulumi.set(__self__, "canonical_id", canonical_id)
        pulumi.set(__self__, "creation_time", creation_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_update_time", last_update_time)
        pulumi.set(__self__, "merged_from_canonical_ids", merged_from_canonical_ids)
        pulumi.set(__self__, "metadata", metadata)
        pulumi.set(__self__, "mount_accessor", mount_accessor)
        pulumi.set(__self__, "mount_path", mount_path)
        pulumi.set(__self__, "mount_type", mount_type)
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="canonicalId")
    def canonical_id(self) -> _builtins.str:
        """
        Canonical ID of the Alias
        """
        return pulumi.get(self, "canonical_id")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> _builtins.str:
        """
        Creation time of the Alias
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the alias
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> _builtins.str:
        """
        Last update time of the alias
        """
        return pulumi.get(self, "last_update_time")

    @_builtins.property
    @pulumi.getter(name="mergedFromCanonicalIds")
    def merged_from_canonical_ids(self) -> Sequence[_builtins.str]:
        """
        List of canonical IDs merged with this alias
        """
        return pulumi.get(self, "merged_from_canonical_ids")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Mapping[str, _builtins.str]:
        """
        Arbitrary metadata
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter(name="mountAccessor")
    def mount_accessor(self) -> _builtins.str:
        """
        Authentication mount acccessor which this alias belongs to
        """
        return pulumi.get(self, "mount_accessor")

    @_builtins.property
    @pulumi.getter(name="mountPath")
    def mount_path(self) -> _builtins.str:
        """
        Authentication mount path which this alias belongs to
        """
        return pulumi.get(self, "mount_path")

    @_builtins.property
    @pulumi.getter(name="mountType")
    def mount_type(self) -> _builtins.str:
        """
        Authentication mount type which this alias belongs to
        """
        return pulumi.get(self, "mount_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the alias
        """
        return pulumi.get(self, "name")


