# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SecretBackendRoleAllowedUserKeyConfig',
]

@pulumi.output_type
class SecretBackendRoleAllowedUserKeyConfig(dict):
    def __init__(__self__, *,
                 lengths: Sequence[_builtins.int],
                 type: _builtins.str):
        """
        :param Sequence[_builtins.int] lengths: List of allowed key lengths, vault-1.10 and above
        :param _builtins.str type: Key type, choices:
               rsa, ecdsa, ec, dsa, ed25519, ssh-rsa, ssh-dss, ssh-ed25519, ecdsa-sha2-nistp256, ecdsa-sha2-nistp384, ecdsa-sha2-nistp521
        """
        pulumi.set(__self__, "lengths", lengths)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def lengths(self) -> Sequence[_builtins.int]:
        """
        List of allowed key lengths, vault-1.10 and above
        """
        return pulumi.get(self, "lengths")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Key type, choices:
        rsa, ecdsa, ec, dsa, ed25519, ssh-rsa, ssh-dss, ssh-ed25519, ecdsa-sha2-nistp256, ecdsa-sha2-nistp384, ecdsa-sha2-nistp521
        """
        return pulumi.get(self, "type")


