# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SecretV2CustomMetadataArgs',
    'SecretV2CustomMetadataArgsDict',
]

MYPY = False

if not MYPY:
    class SecretV2CustomMetadataArgsDict(TypedDict):
        cas_required: NotRequired[pulumi.Input[_builtins.bool]]
        """
        If true, all keys will require the cas parameter to be set on all write requests.
        """
        data: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]
        """
        **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
        secret data from Vault**. A mapping whose keys are the top-level data keys returned from
        Vault and whose values are the corresponding values. This map can only represent string data,
        so any non-string values returned from Vault are serialized as JSON.
        """
        delete_version_after: NotRequired[pulumi.Input[_builtins.int]]
        """
        If set, specifies the length of time before a version is deleted.
        """
        max_versions: NotRequired[pulumi.Input[_builtins.int]]
        """
        The number of versions to keep per key.
        """
elif False:
    SecretV2CustomMetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SecretV2CustomMetadataArgs:
    def __init__(__self__, *,
                 cas_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 data: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 delete_version_after: Optional[pulumi.Input[_builtins.int]] = None,
                 max_versions: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.bool] cas_required: If true, all keys will require the cas parameter to be set on all write requests.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] data: **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
               secret data from Vault**. A mapping whose keys are the top-level data keys returned from
               Vault and whose values are the corresponding values. This map can only represent string data,
               so any non-string values returned from Vault are serialized as JSON.
        :param pulumi.Input[_builtins.int] delete_version_after: If set, specifies the length of time before a version is deleted.
        :param pulumi.Input[_builtins.int] max_versions: The number of versions to keep per key.
        """
        if cas_required is not None:
            pulumi.set(__self__, "cas_required", cas_required)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if delete_version_after is not None:
            pulumi.set(__self__, "delete_version_after", delete_version_after)
        if max_versions is not None:
            pulumi.set(__self__, "max_versions", max_versions)

    @_builtins.property
    @pulumi.getter(name="casRequired")
    def cas_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, all keys will require the cas parameter to be set on all write requests.
        """
        return pulumi.get(self, "cas_required")

    @cas_required.setter
    def cas_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "cas_required", value)

    @_builtins.property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
        secret data from Vault**. A mapping whose keys are the top-level data keys returned from
        Vault and whose values are the corresponding values. This map can only represent string data,
        so any non-string values returned from Vault are serialized as JSON.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "data", value)

    @_builtins.property
    @pulumi.getter(name="deleteVersionAfter")
    def delete_version_after(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If set, specifies the length of time before a version is deleted.
        """
        return pulumi.get(self, "delete_version_after")

    @delete_version_after.setter
    def delete_version_after(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "delete_version_after", value)

    @_builtins.property
    @pulumi.getter(name="maxVersions")
    def max_versions(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of versions to keep per key.
        """
        return pulumi.get(self, "max_versions")

    @max_versions.setter
    def max_versions(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_versions", value)


