# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'UiCustomMessageLinkArgs',
    'UiCustomMessageLinkArgsDict',
]

MYPY = False

if not MYPY:
    class UiCustomMessageLinkArgsDict(TypedDict):
        href: pulumi.Input[_builtins.str]
        """
        The URL of the hyperlink
        """
        title: pulumi.Input[_builtins.str]
        """
        The title of the hyperlink
        """
elif False:
    UiCustomMessageLinkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UiCustomMessageLinkArgs:
    def __init__(__self__, *,
                 href: pulumi.Input[_builtins.str],
                 title: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] href: The URL of the hyperlink
        :param pulumi.Input[_builtins.str] title: The title of the hyperlink
        """
        pulumi.set(__self__, "href", href)
        pulumi.set(__self__, "title", title)

    @_builtins.property
    @pulumi.getter
    def href(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the hyperlink
        """
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "href", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Input[_builtins.str]:
        """
        The title of the hyperlink
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "title", value)


